---
title: "Coda: Code Indexing MCP Server"
linkTitle: Coda Docs
cascade:
  type: docs
menu:
  main:
    name: Coda Docs
    weight: 3
# next: /helix/getting-started
weight: 1
# aliases:
#   - /docs
#   - /docs/overview
---

Coda is a work in progress. Check back soon!
